package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.TdPropertyNetinfo;

/**
 * 涉密网络登记Mapper接口
 * 
 * @author ruoyi
 * @date 2024-05-09
 */
public interface TdPropertyNetinfoMapper 
{
    /**
     * 查询涉密网络登记
     * 
     * @param id 涉密网络登记主键
     * @return 涉密网络登记
     */
    public TdPropertyNetinfo selectTdPropertyNetinfoById(String id);

    public List<TdPropertyNetinfo> selectTdPropertyNetinfoByNetId(String id);

    /**
     * 查询涉密网络登记列表
     * 
     * @param tdPropertyNetinfo 涉密网络登记
     * @return 涉密网络登记集合
     */
    public List<TdPropertyNetinfo> selectTdPropertyNetinfoList(TdPropertyNetinfo tdPropertyNetinfo);


    /**
     * 新增涉密网络登记
     * 
     * @param tdPropertyNetinfo 涉密网络登记
     * @return 结果
     */
    public int insertTdPropertyNetinfo(TdPropertyNetinfo tdPropertyNetinfo);

    /**
     * 修改涉密网络登记
     * 
     * @param tdPropertyNetinfo 涉密网络登记
     * @return 结果
     */
    public int updateTdPropertyNetinfo(TdPropertyNetinfo tdPropertyNetinfo);

    /**
     * 删除涉密网络登记
     * 
     * @param id 涉密网络登记主键
     * @return 结果
     */
    public int deleteTdPropertyNetinfoById(String id);

    /**
     * 批量删除涉密网络登记
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTdPropertyNetinfoByIds(String[] ids);
}
